@@ -1,3 +1,4 @@
 # -*- coding=utf-8 -*-
 from __future__ import absolute_import
-from .command import cli
+
+from .command import cli    # noqa
